# -*- coding: utf-8 -*-

"""Console script for crackhash."""
import sys
import click

from crackhash import __author__, __version__
from crackhash.core import *

ALGORITHMS = [
    "md5",
    "sha1",
    "sha256",
    "sha384",
    "sha512",
    "rmd128",
    "rmd160",
    "rmd256",
    "rmd320",
    "lm",
    "ntlm",
    "mysql",
    "cisco",
    "juniper",
    "gost",
    "whirlpool",
    "ldap_md5",
    "ldap_sha1"
]


def show_banner():
    print((Colors.PURPLE) + (Colors.BOLD) +
          "   ___               _    _               _      ")
    print(r"  / __\ __ __ _  ___| | _| |__   __ _ ___| |__   ")
    print(r" / / | '__/ _` |/ __| |/ / '_ \ / _` / __| '_ \  ")
    print(r"/ /__| | | (_| | (__|   <| | | | (_| \__ \ | | | ")
    print(r"\____/_|  \__,_|\___|_|\_\_| |_|\__,_|___/_| |_| \n" + (Colors.ENDC))
    print("        --[    Version: " +
          (Colors.YELLOW) +
          (Colors.BOLD) +
          (__version__) +
          (Colors.ENDC) +
          "      ]--")
    print("        --[     Author: " +
          (Colors.CYAN) +
          (Colors.BOLD) +
          (__author__) +
          (Colors.ENDC) +
          "  ]--\n\n")


def prompt_proxy(ctx, param, use_proxy):
    if use_proxy:
        host = ctx.params.get('proxy_host')
        if not host:
            host = click.prompt('Proxy host', default='localhost')

        port = ctx.params.get('proxy_port')
        if not port:
            port = click.prompt('Proxy port', default=9050)

        user = ctx.params.get('proxy_user')
        if not user:
            user = click.prompt('Proxy user', default=None)

        pwd = ctx.params.get('proxy_pass')
        if not pwd:
            pwd = click.prompt('Proxy user\'s password', default=None)
        return (host, port, user, pwd)


@click.command()
@click.option('--use-proxy/--no-proxy', is_flag=True, default=False,
              help='Set a proxy to use', callback=prompt_proxy)
@click.option('--proxy-host', is_eager=True, help='Specify the proxy host')
@click.option('--proxy-port', is_eager=True,
              type=int, help='Specify the proxy port')
@click.option('--proxy-user', is_eager=True, help='Specify a proxy user')
@click.option('--proxy-pass', is_eager=True,
              help='Specify a proxy user\'s password')
@click.option('-a', '--algo', type=click.Choice(ALGORITHMS),
              help='Specify hash\' algorithm')
@click.option('-h', '--hash', help='Specify a hash to crack')
@click.option('-f', '--file', type=click.Path(exists=True),
              help='Specify file containing hashes, formatted this way: hashtype:hashvalue')
def main(use_proxy, proxy_host, proxy_port,
         proxy_user, proxy_pass, algo, hash, file):
    """Crackhash is a tool that try to crack different types of hashes using free online services."""
    if (hash == False) and (file == False):
        print_error("Have to set a 'hash' or 'file' argument!")
        return 0
    if hash and file:
        print_error(
            "Can't set both options at once. Choose between 'hash' or 'file' argument!")
        return 0

    sc = Crackhash()

    if hash and (algo is None):
        algo = sc.get_algo(hash)
        print_info(
            'The hash you are looking for probably is %s%s%s' %
            (Colors.BOLD, algo.upper(), Colors.ENDC))
        if not sc.validate_hash(hash, algo):
            print_error('The hash is not supported')
            return 0

    if use_proxy:
        proxy = {
            'host': proxy_host,
            'port': proxy_port,
            'user': proxy_user,
            'pass': proxy_pass,
        }
        sc.start(proxy=proxy)
    else:
        sc.start()

    if file:
        sc.batch(file)
    else:
        sc.check(hash, algo)

    sc.close()
    return 0


if __name__ == "__main__":
    show_banner()
    sys.exit(main())  # pragma: no cover



# -*- coding: utf -*-

import re
import json
from selenium.webdriver.common.keys import Keys


def myaddr(browser, hashvalue, hashtype):
    browser.driver.get(
        'http://md5.my-addr.com/md5_decrypt-md5_cracker_online/md5_decoder_tool.php')
    search_input = browser.driver.find_element_by_name('md5')
    search_input.click()
    search_input.send_keys(hashvalue)

    search_input.send_keys(Keys.RETURN)
    #form = browser.driver.find_element_by_name('f1')
    # form.submit1()
    #button = browser.driver.find_element_by_xpath("//input[@title='go >>>']")
    # button.click()
    browser.wait_page_has_loaded()
    elem = browser.wait_until_element_exists(
        'xpath', '//div[@class="search_result"]')
    html = elem.get_attribute('innerHTML')
    match = re.findall(r"Hashed string</span>: (.*)</div>", html)[0]
    if match:
        return match
    else:
        return False


def nitrxgen(browser, hashvalue, hashtype):
    browser.driver.get("https://www.nitrxgen.net/md5db/" + hashvalue)
    clean = re.compile('<.*?>')
    match = re.sub(clean, '', browser.driver.page_source)
    if match:
        return match
    else:
        return False


def md5decrypt(browser, hashvalue, hashtype):
    if (hashtype == 'md5') or (hashtype == 'ldap_md5'):
        browser.driver.get("https://md5decrypt.net/")
    elif hashtype == 'ldap_sha1':
        browser.driver.get("https://md5decrypt.net/Sha1")
    else:
        browser.driver.get("https://md5decrypt.net/%s" % hashtype.capitalize())

    browser.driver.find_element_by_id("hash_input").send_keys(hashvalue)
    browser.driver.find_element_by_name("decrypt").click()
    browser.wait_page_has_loaded()
    match = browser.wait_until_element_exists('xpath', '//*[@id="answer"]/b')
    if match.text:
        return match.text
    else:
        return False


def hashcrack(browser, hashvalue, hashtype):
    browser.driver.get("https://hashcrack.com/lookup.js?hash=" + hashvalue)
    clean = re.compile('<.*?>')
    res = re.sub(clean, '', browser.driver.page_source)
    match = json.loads(res)
    if match['success'] and match['plain']:
        return match['plain']
    else:
        return False


def hashtoolkit(browser, hashvalue, hashtype):
    browser.driver.get(
        "https://hashtoolkit.com/reverse-hash/?hash=" +
        hashvalue)
    browser.wait_page_has_loaded()
    match = browser.driver.find_element_by_xpath(
        "//span[@title='decrypted " + hashtype + " hash']").text
    if match:
        return match
    else:
        return False


def md5hashing(browser, hashvalue, hashtype):
    if 'rmd' in hashtype:
        ht = 'ripemd' + str(int(''.join(filter(str.isdigit, hashtype))))
        browser.driver.get(
            "https://md5hashing.net/hash/" +
            ht +
            "/" +
            str(hashvalue))
    else:
        browser.driver.get(
            "https://md5hashing.net/hash/" +
            hashtype +
            "/" +
            str(hashvalue))
    elem = browser.wait_until_element_exists('id', 'decodedValue')
    match = elem.text
    if match:
        return match
    else:
        return False


def hashkiller(browser, hashvalue, hashtype):
    if hashtype == 'md5':
        browser.driver.get("https://hashkiller.co.uk/Cracker/MD5")
    elif hashtype == 'sha1':
        browser.driver.get("https://hashkiller.co.uk/Cracker/SHA1")
    elif hashtype == 'sha256':
        browser.driver.get("https://hashkiller.co.uk/Cracker/SHA256")
    elif hashtype == 'sha512':
        browser.driver.get("https://hashkiller.co.uk/Cracker/SHA512")
    elif hashtype == 'ntlm':
        browser.driver.get("https://hashkiller.co.uk/Cracker/NTLM")
    elif hashtype == 'mysql':
        browser.driver.get("https://hashkiller.co.uk/Cracker/MySQL5")

    browser.driver.find_element_by_id('txtHashList').send_keys(hashvalue)

    # browser.driver.find_element_by_xpath('//*[@id="btnCrack"]').click()
    browser.driver.find_element_by_id('btnCrack').click()
    browser.wait_page_has_loaded()
    elem = browser.wait_until_element_exists('xpath', '//*[@id="pass_0"]')
    match = elem.text
    if match:
        return match
    else:
        return False


def passworddecrypt(browser, hashvalue, hashtype):
    browser.driver.get("http://password-decrypt.com/" + hashtype + ".cgi")
    if hashtype == 'cisco':
        browser.driver.find_element_by_name(
            'cisco_password').send_keys(hashvalue)
    elif hashtype == 'juniper':
        browser.driver.find_element_by_name(
            'juniper_password').send_keys(hashvalue)
    browser.driver.find_element_by_css_selector("input:nth-child(4)").click()
    res = browser.wait_until_element_exists('css', 'b')
    match = res.text
    if match:
        return match
    else:
        return False


def m00nie(browser, hashvalue, hashtype):
    if hashtype == 'cisco':
        browser.driver.get("https://www.m00nie.com/type-7-password-tool/")
    elif hashtype == 'juniper':
        browser.driver.get(
            "https://www.m00nie.com/juniper-type-9-password-tool/")
    browser.driver.switch_to.frame(0)
    browser.driver.find_element_by_css_selector(
        "form > input:nth-child(2)").click()
    browser.driver.find_element_by_name("string").click()
    browser.driver.find_element_by_name("string").send_keys(hashvalue)

    browser.driver.find_element_by_name("string").send_keys(Keys.RETURN)
    # browser.driver.find_element_by_css_selector("input:nth-child(3)").click()

    browser.wait_page_has_loaded()
    elem = browser.driver.find_element_by_id('result').text
    match = elem.split(' ')[-1]
    if match:
        return match
    else:
        return False


def firewallruletest(browser, hashvalue, hashtype):
    browser.driver.get(
        "http://firewallruletest.com/cisco/type7dec/?type7pass=" +
        hashvalue)
    clean = re.compile('<.*?>')
    match = re.sub(clean, '', browser.driver.page_source)
    if match:
        return match
    else:
        return False


def ifm(browser, hashvalue, hashtype):
    browser.driver.get("http://www.ifm.net.nz/cookbooks/passwordcracker.html")
    browser.driver.find_element_by_name("crypttext").send_keys(hashvalue)
    browser.driver.find_element_by_xpath(
        "//input[@value='Crack Password']").click()
    match = browser.driver.find_element_by_name(
        'plaintext').get_attribute('value')
    if match:
        return match
    else:
        return False


def ibeast(browser, hashvalue, hashtype):
    browser.driver.get("http://ibeast.com/tools/CiscoPassword/index.asp")
    browser.driver.find_element_by_name('txtPassword').send_keys(hashvalue)
    browser.driver.find_element_by_id('submit1').click()
    elem = browser.driver.find_element_by_xpath('/html/body/center/font[3]')
    html = elem.get_attribute('innerHTML')
    #match = re.findall(r"Your password is (.*?)<br>", html)
    match = html.split(' ')[3].split('<br>')[0]
    if match:
        return match
    else:
        return False


def cmd5(browser, hashvalue, hashtype):
    browser.driver.get("https://www.cmd5.org/")
    #select = browser.select_dropdown_by('id', 'ctl00_ContentPlaceHolder1_InputHashType')
    # select.select_by_visible_text('auto')
    cont = browser.driver.find_element_by_id(
        'ctl00_ContentPlaceHolder1_TextBoxInput')
    cont.send_keys(hashvalue)
    # browser.driver.find_element_by_id('ctl00_ContentPlaceHolder1_Button1').click()
    cont.send_keys(Keys.RETURN)

    browser.wait_page_has_loaded()
    match = browser.driver.find_element_by_xpath('//*[@id="LabelAnswer"]').text
    if 'Not Found' in match:
        return False
    else:
        return match


def it64(browser, hashvalue, hashtype):
    browser.driver.get("http://rainbowtables.it64.com/p3.php")
    # browser.driver.switch_to.frame(1)
    # print(browser.driver.page_source)
    browser.driver.find_element_by_xpath(
        '//*[@name="hashe"]').send_keys(hashvalue)
    browser.driver.find_element_by_xpath('//*[@name="ifik"]').click()

    browser.driver.switch_to_window(browser.driver.window_handles[1])

    if len(hashvalue) == 16:
        #elem = browser.wait_until_element_exists('xpath', '//tr[2]/td[3]')
        elem = browser.wait_until_element_exists(
            'css', 'tr:nth-child(2) > td:nth-child(3)')
        match = elem.text
    elif len(hashvalue) == 32:
        elem1 = browser.wait_until_element_exists(
            'css', 'tr:nth-child(2) > td:nth-child(3)')
        elem2 = browser.wait_until_element_exists(
            'css', 'tr:nth-child(3) > td:nth-child(3)')
        match = elem1.text + elem2.text
        match = match.replace(" ", "")

    # Close result tab
    browser.driver.close()
    browser.driver.switch_to_window(browser.driver.window_handles[0])

    if match:
        return match
    else:
        return False



import os
import zipfile
import json
from selenium.webdriver import Chrome
from selenium.webdriver.chrome.options import Options
from selenium.webdriver.support.ui import WebDriverWait, Select
from selenium.webdriver.support import expected_conditions as EC
from selenium.webdriver.common.by import By


class Browser:

    def __init__(self):
        pass

    def start(self, headless=False, proxy=None, user_agent=None):
        global driver
        chrome_options = Options()
        if os.environ.get('ARE_ON_TRAVIS') == 'True':
            chrome_options.add_argument("--no-sandbox")
            chrome_options.add_argument("--disable-gpu")
        if headless:
            chrome_options.add_argument("--headless")
        if proxy:
            proxy = json.loads(proxy)
            manifest_json = """
            {
                "version": "1.0.0",
                "manifest_version": 2,
                "name": "Chrome Proxy",
                "permissions": [
                    "proxy",
                    "tabs",
                    "unlimitedStorage",
                    "storage",
                    "<all_urls>",
                    "webRequest",
                    "webRequestBlocking"
                ],
                "background": {
                    "scripts": ["background.js"]
                },
                "minimum_chrome_version":"22.0.0"
            }
            """

            background_js = """
            var config = {
                    mode: "fixed_servers",
                    rules: {
                      singleProxy: {
                        scheme: "http",
                        host: "%s",
                        port: parseInt(%s)
                      },
                      bypassList: ["localhost"]
                    }
                  };

            chrome.proxy.settings.set({value: config, scope: "regular"}, function() {});

            function callbackFn(details) {
                return {
                    authCredentials: {
                        username: "%s",
                        password: "%s"
                    }
                };
            }

            chrome.webRequest.onAuthRequired.addListener(
                        callbackFn,
                        {urls: ["<all_urls>"]},
                        ['blocking']
            );
            """ % (proxy['host'], proxy['port'], proxy['user'], proxy['pass'])
            pluginfile = 'proxy_auth_plugin.zip'
            with zipfile.ZipFile(pluginfile, 'w') as zp:
                zp.writestr("manifest.json", manifest_json)
                zp.writestr("background.js", background_js)
            chrome_options.add_extension(pluginfile)
            chrome_options.add_argument('--proxy-server=%s' % proxy)
            #chrome_options.add_argument('--proxy-server=%s' % hostname + ":" + port)
        if user_agent:
            chrome_options.add_argument('--user-agent=%s' % user_agent)
        chrome_options.add_argument("--lang=en")
        self.driver = Chrome(options=chrome_options)

    def stop(self):
        self.driver.quit()

    def get_driver(self):
        return self.driver

    def wait_until_element_exists(self, by, value):
        sec = 120
        if by == 'xpath':
            elem = WebDriverWait(
                self.driver, sec).until(
                EC.presence_of_element_located(
                    (By.XPATH, value)))
        elif by == 'id':
            elem = WebDriverWait(
                self.driver, sec).until(
                EC.presence_of_element_located(
                    (By.ID, value)))
        elif by == 'name':
            elem = WebDriverWait(
                self.driver, sec).until(
                EC.presence_of_element_located(
                    (By.NAME, value)))
        elif by == 'css':
            elem = WebDriverWait(
                self.driver, sec).until(
                EC.presence_of_element_located(
                    (By.CSS_SELECTOR, value)))
        return elem

    def wait_page_has_loaded(self):
        while True:
            page_state = self.driver.execute_script(
                'return document.readyState;')
            self.driver.implicitly_wait(1)
            if page_state == 'complete':
                break
        return

    def select_dropdown_by(self, by, value):
        if by == 'xpath':
            elem = Select(self.driver.find_element_by_xpath(value))
        elif by == 'id':
            elem = Select(self.driver.find_element_by_id(value))
        elif by == 'name':
            elem = Select(self.driver.find_element_by_name(value))
        elif by == 'css':
            elem = Select(self.driver.find_element_by_css_selector(value))
        return elem



# -*- coding: utf -*-

import click


class Colors:
    PURPLE = '\033[95m'
    CYAN = '\033[96m'
    BLUE = '\033[94m'
    GREEN = '\033[92m'
    YELLOW = '\033[93m'
    RED = '\033[91m'
    BOLD = '\033[1m'
    ENDC = '\033[0m'


def print_info(message):
    click.echo((Colors.BLUE) + (Colors.BOLD) +
               ("i ") + (Colors.ENDC) + (str(message)))


def print_success(message):
    click.echo((Colors.GREEN) + (Colors.BOLD) +
               ("✔ ") + (Colors.ENDC) + (str(message)))


def print_warning(message):
    click.echo((Colors.YELLOW) + (Colors.BOLD) +
               ("! ") + (Colors.ENDC) + (str(message)))


def print_error(message):
    click.echo((Colors.RED) + (Colors.BOLD) +
               ("✗ ") + (Colors.ENDC) + (str(message)))



# -*- coding: utf-8 -*-

"""Main module."""

import base64
import random
from yaspin import yaspin
from .helpers import *
from .scraper import *
from .browser import *

USER_AGENTS = [
    "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; Crazy Browser 1.0.5)",
    "Mozilla/5.0 (X11; U; Linux amd64; en-US; rv:5.0) Gecko/20110619 Firefox/5.0",
    "Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:2.0b8pre) Gecko/20101213 Firefox/4.0b8pre",
    "Mozilla/5.0 (compatible; MSIE 10.0; Windows NT 6.1; Trident/6.0)",
    "Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 7.1; Trident/5.0)",
    "Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; Trident/5.0) chromeframe/10.0.648.205",
    "Mozilla/5.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0; InfoPath.2; SLCC1; .NET CLR 3.0.4506.2152; .NET CLR 3.5.30729; .NET CLR 2.0.50727)",
    "Opera/9.80 (Windows NT 6.1; U; sv) Presto/2.7.62 Version/11.01",
    "Opera/9.80 (Windows NT 6.1; U; pl) Presto/2.7.62 Version/11.00",
    "Opera/9.80 (X11; Linux i686; U; pl) Presto/2.6.30 Version/10.61",
    "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_0) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.861.0 Safari/535.2",
    "Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.872.0 Safari/535.2",
    "Mozilla/5.0 (Windows NT 6.1) AppleWebKit/535.1 (KHTML, like Gecko) Chrome/14.0.812.0 Safari/535.1"
]

md5 = [
    myaddr,
    nitrxgen,
    cmd5,
    hashcrack,
    md5decrypt,
    hashtoolkit,
    md5hashing,
    hashkiller]
sha1 = [md5decrypt, cmd5, md5hashing, hashkiller]
sha256 = [md5decrypt, cmd5, md5hashing]
sha384 = [md5decrypt, cmd5, md5hashing]
sha512 = [md5decrypt, cmd5, md5hashing]
rmd128 = [md5hashing]
rmd160 = [md5hashing]
rmd256 = [md5hashing]
rmd320 = [md5hashing]
lm = [it64]
ntlm = [md5decrypt, cmd5, hashkiller]
mysql = [cmd5, hashkiller]
cisco = [passworddecrypt, m00nie, firewallruletest, ifm, ibeast]
juniper = [passworddecrypt, m00nie]
gost = [md5hashing]
whirlpool = [md5hashing]
ldap_md5 = [
    myaddr,
    nitrxgen,
    hashcrack,
    md5decrypt,
    hashtoolkit,
    md5hashing,
    hashkiller]
ldap_sha1 = [md5decrypt, md5hashing, hashkiller]


class Crackhash():

    def __init__(self, proxy=None):
        self.browser = Browser()
        self.ua = random.choice(USER_AGENTS)
        self.result = {}

    def start(self, proxy=None):
        if proxy:
            self.browser.start(headless=True, proxy=proxy, user_agent=self.ua)
        else:
            self.browser.start(headless=True, user_agent=self.ua)

    def close(self):
        self.browser.stop()

    def validate_hash(self, hashvalue, algorithm):
        res = False
        if len(hashvalue) == 32 and algorithm == 'md5':
            res = True
        elif len(hashvalue) == 40 and algorithm == 'sha1':
            res = True
        elif len(hashvalue) == 60 and algorithm == 'sha256':
            res = True
        elif len(hashvalue) == 96 and algorithm == 'sha384':
            res = True
        elif len(hashvalue) == 128 and algorithm == 'sha512':
            res = True
        elif len(hashvalue) == 32 and algorithm == 'rmd128':
            res = True
        elif len(hashvalue) == 40 and algorithm == 'rmd160':
            res = True
        elif len(hashvalue) == 64 and algorithm == 'rmd256':
            res = True
        elif len(hashvalue) == 80 and algorithm == 'rmd320':
            res = True
        elif len(hashvalue) == 32 and algorithm == 'lm':
            res = True
        elif len(hashvalue) == 32 and algorithm == 'ntlm':
            res = True
        elif (len(hashvalue) == 16 or len(hashvalue) == 40) and algorithm == 'mysql':
            res = True
        elif hashvalue.startswith('$9$') and algorithm == 'juniper':
            res = True
        elif algorithm == 'cisco':
            res = True
        elif len(hashvalue) == 60 and algorithm == 'gost':
            res = True
        elif len(hashvalue) == 128 and algorithm == 'whirlpool':
            res = True
        elif hashvalue.startswith('{MD5}') and algorithm == 'ldap_md5':
            res = True
        elif hashvalue.startswith('{SHA}') and algorithm == 'ldap_sha1':
            res = True
        else:
            res = False

        return res

    def get_algo(self, hashvalue):
        algo = ''
        if len(hashvalue) == 32:
            algo = 'md5'
        elif len(hashvalue) == 40:
            algo = 'sha1'
        elif len(hashvalue) == 60:
            algo = 'sha256'
        elif len(hashvalue) == 96:
            algo = 'sha384'
        elif len(hashvalue) == 128:
            algo = 'sha512'
        elif len(hashvalue) == 32:
            algo = 'rmd128'
        elif len(hashvalue) == 40:
            algo = 'rmd160'
        elif len(hashvalue) == 64:
            algo = 'rmd256'
        elif len(hashvalue) == 80:
            algo = 'rmd320'
        elif len(hashvalue) == 32:
            algo = 'lm'
        elif len(hashvalue) == 32:
            algo = 'ntlm'
        elif (len(hashvalue) == 16 or len(hashvalue) == 40):
            algo = 'mysql'
        elif hashvalue.startswith('$9$'):
            algo = 'juniper'
        elif hashvalue == 'cisco':
            algo = 'cisco'
        elif len(hashvalue) == 60:
            algo = 'gost'
        elif len(hashvalue) == 128:
            algo = 'whirlpool'
        elif hashvalue.startswith('{MD5}'):
            algo = 'ldap_md5'
        elif hashvalue.startswith('{SHA}'):
            algo = 'ldap_sha1'
        else:
            algo = ''

        return algo

    def check(self, hashvalue, algorithm):
        if algorithm == 'md5':
            self.check_md5(hashvalue)
        elif algorithm == 'sha1':
            self.check_sha1(hashvalue)
        elif algorithm == 'sha256':
            self.check_sha256(hashvalue)
        elif algorithm == 'sha384':
            self.check_sha384(hashvalue)
        elif algorithm == 'sha512':
            self.check_sha512(hashvalue)
        elif algorithm == 'rmd128':
            self.check_rmd128(hashvalue)
        elif algorithm == 'rmd160':
            self.check_rmd160(hashvalue)
        elif algorithm == 'rmd256':
            self.check_rmd256(hashvalue)
        elif algorithm == 'rmd320':
            self.check_rmd320(hashvalue)
        elif algorithm == 'lm':
            self.check_lm(hashvalue)
        elif algorithm == 'ntlm':
            self.check_ntlm(hashvalue)
        elif algorithm == 'mysql':
            self.check_mysql(hashvalue)
        elif algorithm == 'juniper':
            self.check_juniper(hashvalue)
        elif algorithm == 'cisco':
            self.check_cisco(hashvalue)
        elif algorithm == 'gost':
            self.check_gost(hashvalue)
        elif algorithm == 'whirlpool':
            self.check_whirlpool(hashvalue)
        elif algorithm == 'ldap_md5':
            self.check_ldap_md5(hashvalue)
        elif algorithm == 'ldap_sha1':
            self.check_ldap_sha1(hashvalue)
        else:
            print_error('This hash is not supported.')

    def batch(self, file):
        lines = []
        with open(file, 'r') as f:
            for line in f:
                lines.append(line.strip('\n'))
        for line in lines:
            hashtype, hashvalue = line.split(':')
            if self.validate_hash(hashvalue, hashtype):
                self.check(hashvalue, hashtype)

    def check_md5(self, hash):
        for api in md5:
            with yaspin(text="Processing...", color="cyan") as sp:
                match = api(self.browser, hash, 'md5')
                if match:
                    sp.ok("✔")
                    print_success("Hash cracked: " +
                                  (Colors.YELLOW) +
                                  (Colors.BOLD) +
                                  "%s" %
                                  match +
                                  (Colors.ENDC))
                    break
                else:
                    if md5.index(api) == len(md5) - 1 and not match:
                        sp.fail("✗")
                        print_error(
                            "Hash not found! Try to crack it yourself.")

    def check_sha1(self, hash):
        for api in sha1:
            with yaspin(text="Processing...", color="cyan") as sp:
                match = api(self.browser, hash, 'sha1')
                if match:
                    sp.ok("✔")
                    print_success("Hash cracked: " +
                                  (Colors.YELLOW) +
                                  (Colors.BOLD) +
                                  "%s" %
                                  match +
                                  (Colors.ENDC))
                    break
                else:
                    if sha1.index(api) == len(sha1) - 1 and not match:
                        sp.fail("✗")
                        print_error(
                            "Hash not found! Try to crack it yourself.")

    def check_sha256(self, hash):
        for api in sha256:
            with yaspin(text="Processing...", color="cyan") as sp:
                match = api(self.browser, hash, 'sha256')
                if match:
                    sp.ok("✔")
                    print_success("Hash cracked: " +
                                  (Colors.YELLOW) +
                                  (Colors.BOLD) +
                                  "%s" %
                                  match +
                                  (Colors.ENDC))
                    break
                else:
                    if sha256.index(api) == len(sha256) - 1 and not match:
                        sp.fail("✗")
                        print_error(
                            "Hash not found! Try to crack it yourself.")

    def check_sha384(self, hash):
        for api in sha384:
            with yaspin(text="Processing...", color="cyan") as sp:
                match = api(self.browser, hash, 'sha384')
                if match:
                    sp.ok("✔")
                    print_success("Hash cracked: " +
                                  (Colors.YELLOW) +
                                  (Colors.BOLD) +
                                  "%s" %
                                  match +
                                  (Colors.ENDC))
                    break
                else:
                    if sha384.index(api) == len(sha384) - 1 and not match:
                        sp.fail("✗")
                        print_error(
                            "Hash not found! Try to crack it yourself.")

    def check_sha512(self, hash):
        for api in sha512:
            with yaspin(text="Processing...", color="cyan") as sp:
                match = api(self.browser, hash, 'sha512')
                if match:
                    sp.ok("✔")
                    print_success("Hash cracked: " +
                                  (Colors.YELLOW) +
                                  (Colors.BOLD) +
                                  "%s" %
                                  match +
                                  (Colors.ENDC))
                    break
                else:
                    if sha512.index(api) == len(sha512) - 1 and not match:
                        sp.fail("✗")
                        print_error(
                            "Hash not found! Try to crack it yourself.")

    def check_rmd128(self, hash):
        for api in rmd128:
            with yaspin(text="Processing...", color="cyan") as sp:
                match = api(self.browser, hash, 'rmd128')
                if match:
                    sp.ok("✔")
                    print_success("Hash cracked: " +
                                  (Colors.YELLOW) +
                                  (Colors.BOLD) +
                                  "%s" %
                                  match +
                                  (Colors.ENDC))
                    break
                else:
                    if rmd128.index(api) == len(rmd128) - 1 and not match:
                        sp.fail("✗")
                        print_error(
                            "Hash not found! Try to crack it yourself.")

    def check_rmd160(self, hash):
        for api in rmd160:
            with yaspin(text="Processing...", color="cyan") as sp:
                match = api(self.browser, hash, 'rmd160')
                if match:
                    sp.ok("✔")
                    print_success("Hash cracked: " +
                                  (Colors.YELLOW) +
                                  (Colors.BOLD) +
                                  "%s" %
                                  match +
                                  (Colors.ENDC))
                    break
                else:
                    if rmd160.index(api) == len(rmd160) - 1 and not match:
                        sp.fail("✗")
                        print_error(
                            "Hash not found! Try to crack it yourself.")

    def check_rmd256(self, hash):
        for api in rmd256:
            with yaspin(text="Processing...", color="cyan") as sp:
                match = api(self.browser, hash, 'rmd256')
                if match:
                    sp.ok("✔")
                    print_success("Hash cracked: " +
                                  (Colors.YELLOW) +
                                  (Colors.BOLD) +
                                  "%s" %
                                  match +
                                  (Colors.ENDC))
                    break
                else:
                    if rmd256.index(api) == len(rmd256) - 1 and not match:
                        sp.fail("✗")
                        print_error(
                            "Hash not found! Try to crack it yourself.")

    def check_rmd320(self, hash):
        for api in rmd320:
            with yaspin(text="Processing...", color="cyan") as sp:
                match = api(self.browser, hash, 'rmd320')
                if match:
                    sp.ok("✔")
                    print_success("Hash cracked: " +
                                  (Colors.YELLOW) +
                                  (Colors.BOLD) +
                                  "%s" %
                                  match +
                                  (Colors.ENDC))
                    break
                else:
                    if rmd320.index(api) == len(rmd320) - 1 and not match:
                        sp.fail("✗")
                        print_error(
                            "Hash not found! Try to crack it yourself.")

    def check_lm(self, hash):
        for api in lm:
            with yaspin(text="Processing...", color="cyan") as sp:
                match = api(self.browser, hash, 'lm')
                if match:
                    sp.ok("✔")
                    print_success("Hash cracked: " +
                                  (Colors.YELLOW) +
                                  (Colors.BOLD) +
                                  "%s" %
                                  match +
                                  (Colors.ENDC))
                    break
                else:
                    if lm.index(api) == len(lm) - 1 and not match:
                        sp.fail("✗")
                        print_error(
                            "Hash not found! Try to crack it yourself.")

    def check_ntlm(self, hash):
        for api in ntlm:
            with yaspin(text="Processing...", color="cyan") as sp:
                match = api(self.browser, hash, 'ntlm')
                if match:
                    sp.ok("✔")
                    print_success("Hash cracked: " +
                                  (Colors.YELLOW) +
                                  (Colors.BOLD) +
                                  "%s" %
                                  match +
                                  (Colors.ENDC))
                    break
                else:
                    if ntlm.index(api) == len(ntlm) - 1 and not match:
                        sp.fail("✗")
                        print_error(
                            "Hash not found! Try to crack it yourself.")

    def check_mysql(self, hash):
        for api in mysql:
            with yaspin(text="Processing...", color="cyan") as sp:
                match = api(self.browser, hash, 'mysql')
                if match:
                    sp.ok("✔")
                    print_success("Hash cracked: " +
                                  (Colors.YELLOW) +
                                  (Colors.BOLD) +
                                  "%s" %
                                  match +
                                  (Colors.ENDC))
                    break
                else:
                    if mysql.index(api) == len(mysql) - 1 and not match:
                        sp.fail("✗")
                        print_error(
                            "Hash not found! Try to crack it yourself.")

    def check_cisco(self, hash):
        for api in cisco:
            with yaspin(text="Processing...", color="cyan") as sp:
                match = api(self.browser, hash, 'cisco')
                if match:
                    sp.ok("✔")
                    print_success("Hash cracked: " +
                                  (Colors.YELLOW) +
                                  (Colors.BOLD) +
                                  "%s" %
                                  match +
                                  (Colors.ENDC))
                    break
                else:
                    if cisco.index(api) == len(cisco) - 1 and not match:
                        sp.fail("✗")
                        print_error(
                            "Hash not found! Try to crack it yourself.")

    def check_juniper(self, hash):
        for api in juniper:
            with yaspin(text="Processing...", color="cyan") as sp:
                match = api(self.browser, hash, 'juniper')
                if match:
                    sp.ok("✔")
                    print_success("Hash cracked: " +
                                  (Colors.YELLOW) +
                                  (Colors.BOLD) +
                                  "%s" %
                                  match +
                                  (Colors.ENDC))
                    break
                else:
                    if juniper.index(api) == len(juniper) - 1 and not match:
                        sp.fail("✗")
                        print_error(
                            "Hash not found! Try to crack it yourself.")

    def check_gost(self, hash):
        for api in gost:
            with yaspin(text="Processing...", color="cyan") as sp:
                match = api(self.browser, hash, 'gost')
                if match:
                    sp.ok("✔")
                    print_success("Hash cracked: " +
                                  (Colors.YELLOW) +
                                  (Colors.BOLD) +
                                  "%s" %
                                  match +
                                  (Colors.ENDC))
                    break
                else:
                    if gost.index(api) == len(gost) - 1 and not match:
                        sp.fail("✗")
                        print_error(
                            "Hash not found! Try to crack it yourself.")

    def check_whirlpool(self, hash):
        for api in whirlpool:
            with yaspin(text="Processing...", color="cyan") as sp:
                match = api(self.browser, hash, 'whirlpool')
                if match:
                    sp.ok("✔")
                    print_success("Hash cracked: " +
                                  (Colors.YELLOW) +
                                  (Colors.BOLD) +
                                  "%s" %
                                  match +
                                  (Colors.ENDC))
                    break
                else:
                    if whirlpool.index(api) == len(
                            whirlpool) - 1 and not match:
                        sp.fail("✗")
                        print_error(
                            "Hash not found! Try to crack it yourself.")

    def check_ldap_md5(self, hash):
        hash = str(base64.b64decode(hash[5:])).replace(
            "b'", "").replace("\\n'", "")
        for api in ldap_md5:
            with yaspin(text="Processing...", color="cyan") as sp:
                match = api(self.browser, hash, 'md5')
                if match:
                    sp.ok("✔")
                    print_success("Hash cracked: " +
                                  (Colors.YELLOW) +
                                  (Colors.BOLD) +
                                  "%s" %
                                  match +
                                  (Colors.ENDC))
                    break
                else:
                    if ldap_md5.index(api) == len(ldap_md5) - 1 and not match:
                        sp.fail("✗")
                        print_error(
                            "Hash not found! Try to crack it yourself.")

    def check_ldap_sha1(self, hash):
        hash = str(base64.b64decode(hash[5:])).replace(
            "b'", "").replace("\\n'", "")
        for api in ldap_sha1:
            with yaspin(text="Processing...", color="cyan") as sp:
                match = api(self.browser, hash, 'sha1')
                if match:
                    sp.ok("✔")
                    print_success("Hash cracked: " +
                                  (Colors.YELLOW) +
                                  (Colors.BOLD) +
                                  "%s" %
                                  match +
                                  (Colors.ENDC))
                    break
                else:
                    if ldap_sha1.index(api) == len(
                            ldap_sha1) - 1 and not match:
                        sp.fail("✗")
                        print_error(
                            "Hash not found! Try to crack it yourself.")



# -*- coding: utf-8 -*-

"""Top-level package for Crackhash."""

__author__ = '5h4d0wb0y'
__email__ = '5h4d0wb0y@protonmail.com'
__version__ = '1.0.1'
__description__ = 'Crackhash is a tool that try to crack different types of hashes using free online services.'
__copyright__ = "2019, 5h4dowboy"


#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

import os
from setuptools import setup, find_packages


with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = [
    'Click>=6.0',
    'selenium>=3.141.0',
    'yaspin>=0.14.0',
]

setup_requirements = []

test_requirements = []

about = {}
here = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(here, 'crackhash', '__init__.py')) as f:
    exec(f.read(), about)


setup(
    author=about['__author__'],
    author_email=about['__email__'],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    description=about['__description__'],
    entry_points={
        'console_scripts': [
            'crackhash=crackhash.cli:main',
        ],
    },
    install_requires=requirements,
    license="GNU General Public License v3",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='crackhash',
    name='crackhash',
    packages=find_packages(include=['crackhash']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/5h4d0wb0y/crackhash',
    version=about['__version__'],
    zip_safe=False,
)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Tests for `crackhash` package."""

import base64
import unittest
from click.testing import CliRunner

from crackhash import scraper
from crackhash import browser
from crackhash import cli

# Hashes of common word 'password'
md5 = "5f4dcc3b5aa765d61d8327deb882cf99"
sha1 = "5baa61e4c9b93f3f0682250b6cf8331b7ee68fd8"
sha256 = "5e884898da28047151d0e56f8dc6292773603d0d6aabbdd62a11ef721d1542d8"
sha384 = "a8b64babd0aca91a59bdbb7761b421d4f2bb38280d3a75ba0f21f2bebc45583d446c598660c94ce680c47d19c30783a7"
sha512 = "b109f3bbbc244eb82441917ed06d618b9008dd09b3befd1b5e07394c706a8bb980b1d7785e5976ec049b46df5f1326af5a2ea6d103fd07c95385ffab0cacbc86"
ripemd128 = "c9c6d316d6dc4d952a789fd4b8858ed7"
ripemd160 = "2c08e8f5884750a7b99f6f2f342fc638db25ff31"
ripemd256 = "f94cf96c79103c3ccad10d308c02a1db73b986e2c48962e96ecd305e0b80ef1b"
ripemd320 = "c571d82e535de67ff5f87e417b3d53125f2d83ed7598b89d74483e6c0dfe8d86e88b380249fc8fb4"
mysql = "*2470C0C06DEE42FD1618BB99005ADCA2EC9D1E19"
lm = "E52CAC67419A9A224A3B108F3FA6CB6D"
ntlm = "8846F7EAEE8FB117AD06BDD830B7586C"
whirlpool = "74dfc2b27acfa364da55f93a5caee29ccad3557247eda238831b3e9bd931b01d77fe994e4f12b9d4cfa92a124461d2065197d8cf7f33fc88566da2db2a4d6eae"
gost = "db4d9992897eda89b50f1d3208db607902da7e79c6f3bc6e6933cc5919068564"
cisco = "021605481811003348"
juniper = "$9$QHbgz/tu0IcrvBIwgJDmPBIEhSe"
ldap_md5 = "{MD5}NWY0ZGNjM2I1YWE3NjVkNjFkODMyN2RlYjg4MmNmOTkK"
ldap_sha1 = "{SHA}NWJhYTYxZTRjOWI5M2YzZjA2ODIyNTBiNmNmODMzMWI3ZWU2OGZkOAo="


class TestCrackhash(unittest.TestCase):
    """Tests for `crackhash` package."""

    def setUp(self):
        """Start browser."""
        self.browser = browser.Browser()
        self.browser.start(headless=False)

    def test_command_line_interface(self):
        """Test the CLI."""
        runner = CliRunner()
        help_result = runner.invoke(cli.main, ['--help'])
        assert help_result.exit_code == 0
        assert '--help                          Show this message and exit.' in help_result.output

    #
    # MD5 tests
    #
    def test_md5_myaddr(self):
        """Test MDA5 hash with myaddr."""
        res = scraper.myaddr(self.browser, md5, 'md5')
        assert res == 'password'

    def test_md5_nitrxgen(self):
        """Test MDA5 hash with nitrxgen."""
        res = scraper.nitrxgen(self.browser, md5, 'md5')
        assert res == 'password'

    def test_md5_cmd5(self):
        """Test MDA5 hash with cmd5."""
        res = scraper.cmd5(self.browser, md5, 'md5')
        assert res == 'password'

    def test_md5_hashcrack(self):
        """Test MDA5 hash with hashcrack."""
        res = scraper.hashcrack(self.browser, md5, 'md5')
        assert res == 'password'

    def test_md5_md5decrypt(self):
        """Test MDA5 hash with md5decrypt."""
        res = scraper.md5decrypt(self.browser, md5, 'md5')
        assert res == 'password'

    def test_md5_hashtoolkit(self):
        """Test MDA5 hash with hashtoolkit."""
        res = scraper.hashtoolkit(self.browser, md5, 'md5')
        assert res == 'password'

    def test_md5_md5hashing(self):
        """Test MDA5 hash with md5hashing."""
        res = scraper.md5hashing(self.browser, md5, 'md5')
        assert res == 'password'

    def test_md5_hashkiller(self):
        """Test MDA5 hash with hashkiller."""
        res = scraper.hashkiller(self.browser, md5, 'md5')
        assert res == 'password'

    #
    # SHA1 Tests
    #
    def test_sha1_md5decrypt(self):
        """Test SHA1 hash with md5decrypt."""
        res = scraper.md5decrypt(self.browser, sha1, 'sha1')
        assert res == 'password'

    def test_sha1_cmd5(self):
        """Test SHA1 hash with cmd5."""
        res = scraper.cmd5(self.browser, sha1, 'sha1')
        assert res == 'password'

    # def test_sha1_hashcrack(self):
    #    """Test SHA1 hash with hashcrack."""
    #    res = scraper.hashcrack(self.browser, sha1, 'sha1')
    #    assert res == 'password'

    def test_sha1_md5hashing(self):
        """Test SHA1 hash with md5hashing."""
        res = scraper.md5hashing(self.browser, sha1, 'sha1')
        assert res == 'password'

    def test_sha1_hashkiller(self):
        """Test SHA1 hash with hashkiller."""
        res = scraper.hashkiller(self.browser, sha1, 'sha1')
        assert res == 'password'

    #
    # SHA256 Tests
    #
    def test_sha256_md5decrypt(self):
        """Test SHA256 hash with md5decrypt."""
        res = scraper.md5decrypt(self.browser, sha256, 'sha256')
        assert res == 'password'

    def test_sha256_cmd5(self):
        """Test SHA256 hash with cmd5."""
        res = scraper.cmd5(self.browser, sha256, 'sha256')
        assert res == 'password'

    def test_sha256_md5hashing(self):
        """Test SHA256 hash with md5hashing."""
        res = scraper.md5hashing(self.browser, sha256, 'sha256')
        assert res == 'password'

    #
    # SHA384 Tests
    #
    def test_sha384_md5decrypt(self):
        """Test SHA384 hash with md5decrypt."""
        res = scraper.md5decrypt(self.browser, sha384, 'sha384')
        assert res == 'password'

    def test_sha384_cmd5(self):
        """Test SHA384 hash with cmd5."""
        res = scraper.cmd5(self.browser, sha384, 'sha384')
        assert res == 'password'

    def test_sha384_md5hashing(self):
        """Test SHA384 hash with md5hashing."""
        res = scraper.md5hashing(self.browser, sha384, 'sha384')
        assert res == 'password'

    #
    # SHA512 Tests
    #
    def test_sha512_md5decrypt(self):
        """Test SHA512 hash with md5decrypt."""
        res = scraper.md5decrypt(self.browser, sha512, 'sha512')
        assert res == 'password'

    def test_sha512_md5hashing(self):
        """Test SHA512 hash with md5hashing."""
        res = scraper.md5hashing(self.browser, sha512, 'sha512')
        assert res == 'password'

    #
    # RIPEMD128 Tests
    #
    def test_ripemd128_md5hashing(self):
        """Test RIPEMD128 hash with md5hashing."""
        res = scraper.md5hashing(self.browser, ripemd128, 'rmd128')
        assert res == 'password'

    #
    # RIPEMD160 Tests
    #
    def test_ripemd160_md5hashing(self):
        """Test RIPEMD160 hash with md5hashing."""
        res = scraper.md5hashing(self.browser, ripemd160, 'rmd160')
        assert res == 'password'

    #
    # RIPEMD256 Tests
    #
    def test_ripemd256_md5hashing(self):
        """Test RIPEMD256 hash with md5hashing."""
        res = scraper.md5hashing(self.browser, ripemd256, 'rmd256')
        assert res == 'password'

    #
    # RIPEMD320 Tests
    #
    def test_ripemd320_md5hashing(self):
        """Test RIPEMD320 hash with md5hashing."""
        res = scraper.md5hashing(self.browser, ripemd320, 'rmd320')
        assert res == 'password'

    #
    # LM Tests
    #
    def test_lm_it64(self):
        """Test LM hash with it64."""
        res = scraper.it64(self.browser, lm, 'lm')
        assert res == 'password'
    # def test_lm_hashcrack(self):
    #    """Test LM hash with hashcrack."""
    #    res = scraper.hashcrack(self.browser, lm, 'lm')
    #    assert res == 'password'

    #
    # NTLM Tests
    #
    def test_ntlm_md5decrypt(self):
        """Test NTLM hash with md5decrypt."""
        res = scraper.md5decrypt(self.browser, ntlm, 'ntlm')
        assert res == 'password'

    def test_ntlm_cmd5(self):
        """Test NTLM hash with cmd5."""
        res = scraper.cmd5(self.browser, ntlm, 'ntlm')
        assert res == 'password'

    # def test_ntlm_hashcrack(self):
    #    """Test NTLM hash with hashcrack."""
    #    res = scraper.hashcrack(self.browser, ntlm, 'ntlm')
    #    assert res == 'password'

    def test_ntlm_hashkiller(self):
        """Test NTLM hash with hashkiller."""
        res = scraper.hashkiller(self.browser, ntlm, 'ntlm')
        assert res == 'password'

    #
    # MYSQL Tests
    #
    def test_mysql_cmd5(self):
        """Test MYSQL hash with cmd5."""
        res = scraper.cmd5(self.browser, mysql, 'mysql')
        assert res == 'password'

    def test_mysql_hashkiller(self):
        """Test MYSQL hash with hashkiller."""
        res = scraper.hashkiller(self.browser, mysql, 'mysql')
        assert res == 'password'

    # def test_mysql_hashcrack(self):
    #    """Test MYSQL hash with hashcrack."""
    #    res = scraper.hashcrack(self.browser, mysql, 'mysql')
    #    assert res == 'password'

    #
    # CISCO Tests
    #
    def test_cisco_passworddecrypt(self):
        """Test CISCO hash with passworddecrypt."""
        res = scraper.passworddecrypt(self.browser, cisco, 'cisco')
        assert res == 'password'

    def test_cisco_m00nie(self):
        """Test CISCO hash with m00nie."""
        res = scraper.m00nie(self.browser, cisco, 'cisco')
        assert res == 'password'

    def test_cisco_firewallruletest(self):
        """Test CISCO hash with firewallruletest."""
        res = scraper.firewallruletest(self.browser, cisco, 'cisco')
        assert res == 'password'

    def test_cisco_ifm(self):
        """Test CISCO hash with ifm."""
        res = scraper.ifm(self.browser, cisco, 'cisco')
        assert res == 'password'

    def test_cisco_ibeast(self):
        """Test CISCO hash with ibeast."""
        res = scraper.ibeast(self.browser, cisco, 'cisco')
        assert res == 'password'

    #
    # JUNIPER Tests
    #
    def test_juniper_passworddecrypt(self):
        """Test JUNIPER hash with passworddecrypt."""
        res = scraper.passworddecrypt(self.browser, juniper, 'juniper')
        assert res == 'password'

    def test_juniper_m00nie(self):
        """Test JUNIPER hash with m00nie."""
        res = scraper.m00nie(self.browser, juniper, 'juniper')
        assert res == 'password'

    #
    # GOST Tests
    #
    def test_gost_md5hashing(self):
        """Test GOST hash with md5hashing."""
        res = scraper.md5hashing(self.browser, gost, 'gost')
        assert res == 'password'

    #
    # WHIRLPOOL Tests
    #
    def test_whirlpool_md5hashing(self):
        """Test WHIRLPOOL hash with md5hashing."""
        res = scraper.md5hashing(self.browser, whirlpool, 'whirlpool')
        assert res == 'password'

    #
    # LDAP_MD5 Tests
    #

    def test_ldap_md5_myaddr(self):
        """Test LDAP MD5 hash with myaddr."""
        hash = str(base64.b64decode(ldap_md5[5:])).replace(
            "b'", "").replace("\\n'", "")
        res = scraper.myaddr(self.browser, hash, 'md5')
        assert res == 'password'

    def test_ldap_md5_nitrxgen(self):
        """Test LDAP MD5 hash with nitrxgen."""
        hash = str(base64.b64decode(ldap_md5[5:])).replace(
            "b'", "").replace("\\n'", "")
        res = scraper.nitrxgen(self.browser, hash, 'md5')
        assert res == 'password'

    def test_ldap_md5_hashcrack(self):
        """Test LDAP MD5 hash with hashcrack."""
        hash = str(base64.b64decode(ldap_md5[5:])).replace(
            "b'", "").replace("\\n'", "")
        res = scraper.hashcrack(self.browser, hash, 'md5')
        assert res == 'password'

    def test_ldap_md5_md5decrypt(self):
        """Test LDAP MD5 hash with md5decrypt."""
        hash = str(base64.b64decode(ldap_md5[5:])).replace(
            "b'", "").replace("\\n'", "")
        res = scraper.md5decrypt(self.browser, hash, 'md5')
        assert res == 'password'

    def test_ldap_md5_hashtoolkit(self):
        """Test LDAP MD5 hash with hashtoolkit."""
        hash = str(base64.b64decode(ldap_md5[5:])).replace(
            "b'", "").replace("\\n'", "")
        res = scraper.hashtoolkit(self.browser, hash, 'md5')
        assert res == 'password'

    def test_ldap_md5_md5hashing(self):
        """Test LDAP MD5 hash with md5hashing."""
        hash = str(base64.b64decode(ldap_md5[5:])).replace(
            "b'", "").replace("\\n'", "")
        res = scraper.md5hashing(self.browser, hash, 'md5')
        assert res == 'password'

    def test_ldap_md5_hashkiller(self):
        """Test LDAP MD5 hash with hashkiller."""
        hash = str(base64.b64decode(ldap_md5[5:])).replace(
            "b'", "").replace("\\n'", "")
        res = scraper.hashkiller(self.browser, hash, 'md5')
        assert res == 'password'

    #
    # LDAP_SHA1 Tests
    #
    def test_ldap_sha1_md5decrypt(self):
        """Test LDAP SHA1 hash with md5decrypt."""
        hash = str(base64.b64decode(ldap_sha1[5:])).replace(
            "b'", "").replace("\\n'", "")
        res = scraper.md5decrypt(self.browser, hash, 'sha1')
        assert res == 'password'

    # def test_ldap_sha1_hashcrack(self):
    #    """Test LDAP SHA1 hash with hashcrack."""
    #    hash = str(base64.b64decode(ldap_sha1[5:])).replace("b'", "").replace("\\n'", "")
    #    res = scraper.hashcrack(self.browser, hash, 'sha1')
    #    assert res == 'password'

    def test_ldap_sha1_md5hashing(self):
        """Test LDAP SHA1 hash with md5hashing."""
        hash = str(base64.b64decode(ldap_sha1[5:])).replace(
            "b'", "").replace("\\n'", "")
        res = scraper.md5hashing(self.browser, hash, 'sha1')
        assert res == 'password'

    def test_ldap_sha1_hashkiller(self):
        """Test LDAP SHA1 hash with hashkiller."""
        hash = str(base64.b64decode(ldap_sha1[5:])).replace(
            "b'", "").replace("\\n'", "")
        res = scraper.hashkiller(self.browser, hash, 'sha1')
        assert res == 'password'

    def tearDown(self):
        """Stop browser."""
        self.browser.stop()
